pypip# libpythonpro_fls
Modulo para exemplificar construcao de projetos Python no curso Pytools

Nesse Curso eh ensinado como contribuir com projetos de codigo aberto

Link para o curso [Python Pro]
[![Updates](https://pyup.io/repos/github/fabio1008/libpythonpro/shield.svg)](https://pyup.io/repos/github/fabio1008/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/fabio1008/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/fabio1008/libpythonpro/)

Suportada Versao 3 do Python

Para instalar:

'''console
py -3 -m venv .venv
activate
pip install - r requirements-dev.txt
'''

Para conferir qualidade do codigo:
'''console
flake8
'''

Topicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
